/*

    File: file_v2i.c

    Copyright (C) 2012 Christophe GRENIER <grenier@cgsecurity.org>
  
    This software is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
  
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
  
    You should have received a copy of the GNU General Public License along
    with this program; if not, write the Free Software Foundation, Inc., 51
    Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

 */

#if !defined(SINGLE_FORMAT) || defined(SINGLE_FORMAT_v2i)
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef HAVE_STRING_H
#include <string.h>
#endif
#include <stdio.h>
#include "types.h"
#include "filegen.h"

/*@ requires valid_register_header_check(file_stat); */
static void register_header_check_v2i(file_stat_t *file_stat);

const file_hint_t file_hint_v2i = {
  .extension = "v2i",
  .description = "v2i backup",
  .max_filesize = PHOTOREC_MAX_FILE_SIZE,
  .recover = 1,
  .enable_by_default = 1,
  .register_header_check = &register_header_check_v2i
};

/*@
  @ requires buffer_size >= 0x18 ;
  @ requires separation: \separated(&file_hint_v2i, buffer+(..), file_recovery, file_recovery_new);
  @ requires valid_header_check_param(buffer, buffer_size, safe_header_only, file_recovery, file_recovery_new);
  @ ensures  valid_header_check_result(\result, file_recovery_new);
  @ assigns  *file_recovery_new;
  @*/
static int header_check_v2i(const unsigned char *buffer, const unsigned int buffer_size, const unsigned int safe_header_only, const file_recovery_t *file_recovery, file_recovery_t *file_recovery_new)
{
  const unsigned char v2i_sign[4] = { 0x13, 0x04, 0x08, 0x00 };
  if(memcmp(&buffer[0x14], v2i_sign, sizeof(v2i_sign)) == 0)
  {
    reset_file_recovery(file_recovery_new);
    file_recovery_new->extension = file_hint_v2i.extension;
    return 1;
  }
  return 0;
}

static void register_header_check_v2i(file_stat_t *file_stat)
{
  register_header_check(0, "$CAN", 4, &header_check_v2i, file_stat);
}
#endif
